# Air Pollution Data Toolbox

apdt是一个用于空气污染数据研究的工具包，使用它可以方便地：
- 处理不同格式的数据源，例如国控站、移动监测系统、气象观测等；
- 进行常见的数据处理，例如时空插值、滤波、高维信号处理等；
- 进行常见的数据分析，例如因果相关性、事件分析、模式挖掘等；
- 丰富的可视化图表，例如曲线、地图、动态演变等；
- 优雅调参深度学习，帮你完成数据集划分、常见模型的搭建、训练过程的处理等；

我们致力于实现以下目标：
- 数据结构的统一性；
- 方法的高度可复用性；
- 广泛性，在空气污染话题下覆盖数据分析和学术研究的需求；
- 高效率，并行支持大规模数据处理；
